/* 
   Copyright (C) 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/*
 Persistence of Vision Ray Tracer Scene Description File

 File: gnu-tux-black.pov
 Vers: 3.5
 Date: 01/2005
 Auth: Nicolas Rougier
 Cmd : povray +Ignu-tux-black.pov +w1600 +h800 +fn +am2 +P +a0.1
*/

#version 3.5;
#include "colors.inc"
#include "math.inc"


// ========================================
//  Notes
// ========================================

// ========================================
//  Switches
// ========================================
#declare use_radiosity = on;

// ========================================
//  Settings
// ========================================
global_settings {
  #if (use_radiosity)
    radiosity {
      pretrace_start 0.08
      pretrace_end 0.005
      count 600
      error_bound 0.05
      nearest_count 5
      recursion_limit 1
      low_error_factor .5
      gray_threshold 0.0
      minimum_reuse 0.015
      brightness 1.0
      adc_bailout 0.01/2
//      normal on
    }
  #end
}

// ========================================
//  Default settings
// ========================================
#default {
  texture {
    #if (use_radiosity)
      finish {
        ambient 0.0
        diffuse 1.0
      }
    #else
      finish {
        ambient    0.1
        diffuse    0.6
      }
    #end
  }
}


// ========================================
//  Lights
// ========================================
#declare light_distance       = 15;
#declare light_point_at       = <-2,0,0>;
#declare light_area_sharp     = 5;
#declare light_area_diffuse   = 20;
#declare light_area_number    = 10;
#declare spot_radius          = 10;
#declare spot_falloff         = 25;
#declare spot_tightness       = 50;

// Key light
// The key light is the main light that provide most lighting and
// shadows. It is quite a powerful light that is generally placed from
// 30-bÂ° to 45Â° either left or right side of subject. 45Â° is often-A
// preferred because it best brings out silhouette and texture. Choosing
// the right or left side mainly depends of your subject (has it a good
  // left or right profile). Also have in mind that depending on reading
// direction (left to right for some countries, right to left for some
  // others) placing the light left or right will is not innocent and will
// greatly influence your lecture of the image. The vertical placement is
// generally rather high between 30-bÂ° and 45Â°.-A
light_source {
  light_distance*y
  color rgb 1
  fade_distance light_distance fade_power 2
  spotlight radius spot_radius falloff spot_falloff tightness spot_tightness
  area_light light_area_sharp*x, light_area_sharp*z,
  light_area_number, light_area_number
  jitter adaptive 1
  rotate -x*55
  rotate  y*45
  point_at light_point_at
}

// Fill light
// The purpose of the fill light is to fill in shadows produced by the
// key light that would be otherwise too dark and would left part of the
// subject completetly black. The typical placement for a fill light is
// at an horizontal angle of 90-bÂ° from the key light and it is generally-A
// vertically lower than the key light (25-bÂ°). Furthermore, and since you-A
// don't want your fill light to produce parasite shadows, the light has
// to be very diffuse and far less powerful than the key light (half of
  // the power is a good setting).
light_source {
  light_distance*y
  color rgb .35
  fade_distance light_distance fade_power 2
  spotlight radius spot_radius falloff spot_falloff tightness spot_tightness
  area_light light_area_diffuse*x, light_area_diffuse*z,
  light_area_number, light_area_number
  jitter adaptive 1
  rotate -x*65
  rotate -y*35
  point_at light_point_at+y
}

// Back light
// The function of the back light is to separate the subject from the
// background by creating a rim of light around it. It is sometime called
// a hair light and is placed right in front of the camera but behind the
// subject and is generally at the same vertical level as the key light
// or even higher depending of the effect you want to achieve and how
// much separation you want.
light_source {
  light_distance*y
  color rgb .35
  fade_distance light_distance fade_power 2
  spotlight radius spot_radius falloff spot_falloff tightness spot_tightness
  area_light light_area_diffuse*x, light_area_diffuse*z,
  light_area_number, light_area_number
  jitter adaptive 1
  rotate  x*15
  point_at light_point_at+y
}







#declare light_distance       = 15;
#declare light_point_at       = <+2,0,0>;
#declare light_area_sharp     = 5;
#declare light_area_diffuse   = 20;
#declare light_area_number    = 10;
#declare spot_radius          = 10;
#declare spot_falloff         = 25;
#declare spot_tightness       = 50;

// Key light
// The key light is the main light that provide most lighting and
// shadows. It is quite a powerful light that is generally placed from
// 30-bÂ° to 45Â° either left or right side of subject. 45Â° is often-A
// preferred because it best brings out silhouette and texture. Choosing
// the right or left side mainly depends of your subject (has it a good
  // left or right profile). Also have in mind that depending on reading
// direction (left to right for some countries, right to left for some
  // others) placing the light left or right will is not innocent and will
// greatly influence your lecture of the image. The vertical placement is
// generally rather high between 30-bÂ° and 45Â°.-A
light_source {
  light_distance*y
  color rgb 1
  fade_distance light_distance fade_power 2
  spotlight radius spot_radius falloff spot_falloff tightness spot_tightness
  area_light light_area_sharp*x, light_area_sharp*z,
  light_area_number, light_area_number
  jitter adaptive 1
  rotate -x*55
  rotate  y*45
  point_at light_point_at
}

// Fill light
// The purpose of the fill light is to fill in shadows produced by the
// key light that would be otherwise too dark and would left part of the
// subject completetly black. The typical placement for a fill light is
// at an horizontal angle of 90-bÂ° from the key light and it is generally-A
// vertically lower than the key light (25-bÂ°). Furthermore, and since you-A
// don't want your fill light to produce parasite shadows, the light has
// to be very diffuse and far less powerful than the key light (half of
  // the power is a good setting).
light_source {
  light_distance*y
  color rgb .35
  fade_distance light_distance fade_power 2
  spotlight radius spot_radius falloff spot_falloff tightness spot_tightness
  area_light light_area_diffuse*x, light_area_diffuse*z,
  light_area_number, light_area_number
  jitter adaptive 1
  rotate -x*65
  rotate -y*35
  point_at light_point_at+y
}

// Back light
// The function of the back light is to separate the subject from the
// background by creating a rim of light around it. It is sometime called
// a hair light and is placed right in front of the camera but behind the
// subject and is generally at the same vertical level as the key light
// or even higher depending of the effect you want to achieve and how
// much separation you want.
light_source {
  light_distance*y
  color rgb .35
  fade_distance light_distance fade_power 2
  spotlight radius spot_radius falloff spot_falloff tightness spot_tightness
  area_light light_area_diffuse*x, light_area_diffuse*z,
  light_area_number, light_area_number
  jitter adaptive 1
  rotate  x*15
  point_at light_point_at+y
}





// ========================================
//  Camera
// ========================================
#declare EyePos  = <0, 1, -25>;
#declare EyeLook = <0, 1,   0>;
camera {
  location EyePos
  look_at  EyeLook
  direction 1.5*z
  right     x*image_width/image_height
  angle 20
}


// ========================================
//  Sky
// ========================================
sky_sphere {pigment {rgb 0}}


// ========================================
//  Ground
// ========================================
plane {y,0  texture {pigment {rgb 1} finish {ambient 0 diffuse 1}}}
plane {z,100 inverse texture {pigment {rgb 1} finish {ambient 0 diffuse 1}}}

// ========================================
//  Spheric to cartesian conversion macro
// ========================================
#macro spheric (rho,theta,phi)
<rho*sin(theta)*sin(phi), rho*cos(theta), rho*sin(theta)*cos(phi)>
#end


// ========================================
// Textures
// ========================================
#include "furtex.inc"

#declare t_fur       = FurTex (color <60,40,20>*3/256)
#declare t_fur_white = FurTex (color <60,40,20>*4/256)
#declare t_eye_white = texture {pigment{rgb 1}}
#declare t_eye_black = texture {pigment{rgb 0.01} finish {specular 1 roughness 0.005}}
#declare c_horn = rgb<15,10,5>*2.0/255; //rgb<1,0.8,0.6>*0.2;
#declare c_horn2 = rgb<15,10,5>*4.0/255; //rgb<1,0.8,0.6>*0.2;
#local t_horn = texture {
  pigment {
	wood
	turbulence 0.5
	color_map {
	  [0.25 color c_horn]
	  [0.50 color c_horn*0.95]
	  [0.75 color c_horn*1.05]
	}
  }
  scale <10,.5,.5>
  finish {specular .1}
//  rotate 45
}

#local t_horn2 = texture {
  pigment {
	wood
	turbulence 0.5
	color_map {
	  [0.25 color c_horn2]
	  [0.50 color c_horn2*0.95]
	  [0.75 color c_horn2*1.05]
	}
  }
  scale <10,.5,.5>
  finish {specular .1}
//  rotate 45
}


#include "meshgnu.inc"

object {
  gnu
  rotate -x*90
  rotate y*180
  rotate -y*5
  translate -0.025*y
  translate -x*2
}

#include "tux-black.inc"

object {
  tux
  rotate y*5
  translate x*2
}

